@@ -13,7 +13,7 @@ int main(int argc, char *argv[])
   QApplication app(argc, argv);
   QCoreApplication::setOrganizationName("NSL");
   QCoreApplication::setOrganizationDomain("nsl.cz");
-  QCoreApplication::setApplicationName("qCrpc");
+  QCoreApplication::setApplicationName("simplecal");
 
 
   dCalWidget w;
