@@ -3,7 +3,7 @@
 
 #include <QDialog>
 #include <QComboBox>
-#include "WidgetColorPicker.h"
+#include "colorButton.h"
 
 class SettingsDialog : public QDialog
 {
@@ -14,7 +14,7 @@ public:
     ~SettingsDialog();
 
 private:
-    WidgetColorPicker *names, *days, *weekends, *weeks, *cday, *cdayback;
+    ColorButton *names, *days, *weekends, *weeks, *cday, *cdayback;
     QComboBox *lang;
 
 private slots:
